# Benefactor
It's a useful Python snippets collection.

## Status
[![Build Status](https://travis-ci.org/viktorchukhantsev/benefactor.svg?branch=master)](https://travis-ci.org/viktorchukhantsev/benefactor)


